import { ConnectionBackend } from '@angular/http';
import { Injectable } from '@angular/core';
import { NativeHttpBackend } from './native-http-backend';
import { checkAvailability } from '@ionic-native/core';
var NativeHttpFallback = (function () {
    function NativeHttpFallback(nativeHttpBackend, fallback) {
        this.nativeHttpBackend = nativeHttpBackend;
        this.fallback = fallback;
        this.nativeIsForced = null;
        this.nativeIsAvailable = null;
    }
    NativeHttpFallback.prototype.createConnection = function (request) {
        /**
         * Native HTTP Cordova plugin doesn't like local requests
         */
        var isOutgoingRequest = /^(http|https):\/\//.test(request.url);
        if (isOutgoingRequest && this.isNativeHttpAvailable()) {
            return this.nativeHttpBackend.createConnection(request);
        }
        else {
            return this.fallback.createConnection(request);
        }
    };
    /**
     * Enable/disable forced native HTTP usage without preliminary check. Helpful for unit testing
     *
     * @param {boolean} isEnabled
     */
    NativeHttpFallback.prototype.forceNative = function (isEnabled) {
        this.nativeIsForced = isEnabled;
    };
    NativeHttpFallback.prototype.isNativeHttpAvailable = function () {
        if (this.nativeIsForced !== null) {
            return this.nativeIsForced;
        }
        if (this.nativeIsAvailable === null) {
            this.nativeIsAvailable = checkAvailability('cordovaHTTP2') === true;
        }
        return this.nativeIsAvailable;
    };
    NativeHttpFallback.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    NativeHttpFallback.ctorParameters = function () { return [
        { type: NativeHttpBackend, },
        { type: ConnectionBackend, },
    ]; };
    return NativeHttpFallback;
}());
export { NativeHttpFallback };
//# sourceMappingURL=native-http-fallback.js.map